@@ -1,4 +1,6 @@
+from nibiru.query_clients.auth import AuthQueryClient  # noqa
 from nibiru.query_clients.dex import DexQueryClient  # noqa
+from nibiru.query_clients.epoch import EpochQueryClient  # noqa
 from nibiru.query_clients.perp import PerpQueryClient  # noqa
 from nibiru.query_clients.pricefeed import PricefeedQueryClient  # noqa
 from nibiru.query_clients.vpool import VpoolQueryClient  # noqa
